diff --git a/main.c b/main.c
index 16ba36b..0997cfa 100644
--- a/main.c
+++ b/main.c
@@ -74,6 +74,11 @@ int main(int argc, char *argv[])
 	veisp_set_buffers(Y, C);
 	veisp_init_picture(w, h, VEISP_COLOR_FORMAT_NV12);
 
+	/* scale to half the size */
+	w = w * 0.5;
+	h = h * 0.5;
+	veisp_set_scaler(w, h, 0.0, 0.0, 0.5, 0.5);
+
 	veavc_init_vle(J, Jsize);
 	veavc_init_ctrl(VEAVC_ENCODER_MODE_JPEG);
 	veavc_jpeg_parameters(1, 0, 0, 0);
diff --git a/ve.h b/ve.h
index f42412c..1d9d30c 100644
--- a/ve.h
+++ b/ve.h
@@ -111,8 +111,17 @@ extern void *regs;
 #define VE_ISP_PIC_SIZE			0xa00
 #define VE_ISP_PIC_STRIDE		0xa04
 #define VE_ISP_CTRL			0xa08
+#define VE_ISP_TRIG			0xa0c
+#define VE_ISP_SCALER_SIZE		0xa2c
+#define VE_ISP_SCALER_OFFSET_Y		0xa30
+#define VE_ISP_SCALER_OFFSET_C		0xa34
+#define VE_ISP_SCALER_FACTOR		0xa38
+#define VE_ISP_OUTPUT_LUMA		0xa70
+#define VE_ISP_OUTPUT_CHROMA		0xa74
 #define VE_ISP_PIC_LUMA			0xa78
 #define VE_ISP_PIC_CHROMA		0xa7c
+#define VE_ISP_SRAM_INDEX		0xae0
+#define VE_ISP_SRAM_DATA		0xae4
 
 #define VE_AVC_PARAM			0xb04
 #define VE_AVC_QP			0xb08
diff --git a/veisp.c b/veisp.c
index 409e874..ab0c856 100644
--- a/veisp.c
+++ b/veisp.c
@@ -49,3 +49,75 @@ void veisp_init_picture(uint32_t w, uint32_t h, veisp_color_format f)
 	S(format, VE_ISP_CTRL);
 }
 
+
+/*
+ Quick and very hurrily done calculation of the polyphase filter coeficients
+ for bilinear scaling. Table A is for horizontal direction and table B for
+ vertical.
+*/
+void veisp_write_table_A(void)
+{
+	uint16_t h0;
+	uint16_t h1;
+	uint16_t h2;
+	uint16_t h3;
+	uint32_t h1h0;
+	uint32_t h3h2;
+	int i;
+	for(i = 0; i < 16; i++)
+	{
+		h0 = 0;
+		h1 = 0x100 - (i * (0x100/16));
+		h2 = 0x100 - h1;
+		h3 = 0;
+
+		h1h0 = (h1 << 16) | h0;
+		h3h2 = (h3 << 16) | h2;
+		S(h1h0, VE_ISP_SRAM_DATA);
+		S(h3h2, VE_ISP_SRAM_DATA);
+	}
+}
+
+void veisp_write_table_B(void)
+{
+	uint16_t h0;
+	uint16_t h1;
+	uint32_t h1h0;
+	int i;
+	for(i = 0; i < 32; i++)
+	{
+		h0 = 0x100 - (i * (0x100/32));
+		h1 = 0x100 - h0;
+
+		h1h0 = (h1 << 16) | h0;
+		S(h1h0, VE_ISP_SRAM_DATA);
+	}
+}
+
+void veisp_set_scaler(uint32_t newwidth, uint32_t newheight,
+                      float offsetx, float offsety, float scalex, float scaley)
+{
+	uint32_t width_mb  = (newwidth + 15) / 16;
+	uint32_t height_mb = (newwidth + 15) / 16;
+	uint32_t newsize = ((width_mb & 0xff) << 8) | (height_mb & 0xff);
+	uint32_t offx = (0x100 * offsetx);
+	uint32_t offy = (0x100 * offsety);
+	uint32_t offset = ((offy & 0xffff) << 16) | (offx & 0xffff);
+	uint32_t sx = (0x100 / scalex);
+	uint32_t sy = (0x100 / scaley);
+	uint32_t factor = ((sy & 0xfff) << 12) | (sx & 0xfff);
+
+
+	S(newsize, VE_ISP_SCALER_SIZE);
+	S(offset , VE_ISP_SCALER_OFFSET_Y);
+	S(offset , VE_ISP_SCALER_OFFSET_C);
+	S(factor , VE_ISP_SCALER_FACTOR);
+
+	S(0x400, VE_ISP_SRAM_INDEX);
+	veisp_write_table_A();
+	veisp_write_table_B();
+
+	uint32_t ctrl = L(VE_ISP_CTRL) | (1 << 16);
+	S(ctrl, VE_ISP_CTRL);
+}
+
diff --git a/vepoc.h b/vepoc.h
index 942f12f..bf0ec93 100644
--- a/vepoc.h
+++ b/vepoc.h
@@ -46,6 +46,7 @@ void vejpeg_write_file(const char *filename, uint8_t *buffer, uint32_t length);
 void veisp_set_buffers(uint8_t *Y, uint8_t *C);
 void veisp_set_picture_size(uint32_t w, uint32_t h);
 void veisp_init_picture(uint32_t w, uint32_t h, veisp_color_format f);
+void veisp_set_scaler(uint32_t w, uint32_t h, float x, float y, float sx, float sy);
 
 void veavc_select_subengine(void);
 void veavc_init_vle(uint8_t *J, uint32_t size);
